==> cffr_0.2.2.tar.gz: cffr/tests/testthat/_snaps/cff_to_bibtex.md <==
# Article to bibtex

    @Article{knuth:1984,
      author = {{R Core Team}},
      title = {Literate Programming},
      journal = {The Computer Journal},
      year = {1984},
      volume = {27},
      number = {2},
      pages = {97--111},
      month = {January},
      keywords = {Some},
      keywords = {simple},
      keywords = {keywords},
    }

---

    @Article{rcoreteam:1984,
      title = {Literate Programming},
      author = {{R Core Team}},
      year = {1984},
      month = {jan},
      journal = {The Computer Journal},
      volume = {27},
      number = {2},
      pages = {97--111},
      keywords = {Some, simple, keywords},
    }

# Book to bibtex

    @Book{latex:companion,
      author = {Frank Mittelbach and Michel Gossens and Johannes Braams and David Carlisle and Chris Rowley},
      editor = {{{Barnes} and {Noble}}},
      title = {The LaTeX Companion},
      publisher = {Addison-Wesley Professional},
      year = {2004},
      volume = {3},
      number = {7},
      series = {The LateX Books},
      address = {Santa Monica},
      edition = {Fourth},
      month = {August},
      note = {Example modified for testing purposes},
      keywords = {Two, keyword},
    }

---

    @Book{mittelbachgossens:2004,
      title = {The LaTeX Companion},
      author = {Frank Mittelbach and Michel Gossens and Johannes Braams and David Carlisle and Chris Rowley},
      year = {2004},
      month = {aug},
      publisher = {Addison-Wesley Professional},
      address = {Santa Monica},
      editor = {{Barnes and Noble}},
      series = {The LateX Books},
      volume = {3},
      number = {7},
      note = {Example modified for testing purposes},
      edition = {Fourth},
      keywords = {Two, keyword},
    }

# Booklet to bibtex

    @Booklet{Mustermann2016,
      title = {Java Booklet},
      author = {Max Mustermann},
      howpublished = {Internet},
      address = {Stuttgart},
      month = {feb},
      year = {2016},
      note = {Example modified from Jabref},
      keywords = {java},
    }

---

    @Booklet{mustermann:2016,
      title = {Java Booklet},
      author = {Max Mustermann},
      year = {2016},
      month = {feb},
      address = {Stuttgart},
      note = {Example modified from Jabref},
      howpublished = {Internet},
    }

# InBook to bibtex with pages

    @InBook{,
      year = {2003},
      month = {oct},
      pages = {175--196},
      title = {Architectural Mismatch Tolerance},
      chapter = {Tolerances and Other Notes},
      author = {R. {de Lemos} and C. Gacek and A. Romanovsky},
      url = {http://www.cs.kent.ac.uk/pubs/2003/1773},
      publication_type = {inbook},
      submission_id = {12884_1074884456},
      isbn = {3-540-40727-8},
      editor = {A. Lalanda},
      edition = {Fifth},
      publisher = {Springer},
      volume = {2677},
      number = {234},
      address = {Lozoya},
      series = {Lecture Notes in Computer Science},
      type = {Architecting Dependable Systems},
    }

---

    @InBook{delemosgacek:2003,
      title = {Architectural Mismatch Tolerance},
      author = {R. {de Lemos} and C. Gacek and A. Romanovsky},
      year = {2003},
      month = {oct},
      publisher = {Springer},
      address = {Lozoya},
      editor = {A. Lalanda},
      series = {Lecture Notes in Computer Science},
      volume = {2677},
      number = {234},
      pages = {175--196},
      isbn = {3-540-40727-8},
      url = {http://www.cs.kent.ac.uk/pubs/2003/1773},
      chapter = {Tolerances and Other Notes},
      edition = {Fifth},
    }

# InCollection to bibtex

    @InCollection{,
      author = {Klaus Abels},
      title = {Who Gives a Damn about Minimizers in Questions?},
      booktitle = {Proceedings from Semantics and Linguistic Theory {XIII}},
      publisher = {Cornell University},
      year = {2003},
      editor = {Robert B. Young and Yuping Zhou},
      pages = {1--18},
      address = {Ithaca, New York},
      topic = {interrogatives;nl-semantics;polarity;},
    }

---

    @InCollection{abels:2003,
      title = {Who Gives a Damn about Minimizers in Questions?},
      author = {Klaus Abels},
      year = {2003},
      booktitle = {Proceedings from Semantics and Linguistic Theory XIII},
      publisher = {Cornell University},
      address = {Ithaca, New York},
      editor = {Robert B. Young and Yuping Zhou},
      pages = {1--18},
    }

# InProceedings to bibtex

    @InProceedings{,
      author = {John Aberdeen and Samuel Bayer and Sasha Caskey and Laurie Damianos and Alan Goldschen and Lynette Hirschman and Dan Loehr and Hugo Trapper},
      title = {Implementing Practical Dialogue Systems with the
                        {DARPA} Communicator Architecture},
      booktitle = {Proceedings of the {IJCAI}-99 Workshop on
                        Knowledge and Reasoning in Practical Dialogue Systems},
      year = {1999},
      editor = {Jan Alexandersson},
      pages = {81--86},
      series = {A Series},
      organization = {IJCAI},
      publisher = {International Joint Conference on Artificial Intelligence},
      address = {Murray Hill, New Jersey},
    }

---

    @InProceedings{aberdeenbayer:1999,
      title = {Implementing Practical Dialogue Systems with the DARPA Communicator Architecture},
      author = {John Aberdeen and Samuel Bayer and Sasha Caskey and Laurie Damianos and Alan Goldschen and Lynette Hirschman and Dan Loehr and Hugo Trapper},
      year = {1999},
      booktitle = {Proceedings of the IJCAI-99 Workshop on Knowledge and Reasoning in Practical Dialogue Systems},
      publisher = {International Joint Conference on Artificial Intelligence},
      address = {Murray Hill, New Jersey},
      editor = {Jan Alexandersson},
      series = {A Series},
      pages = {81--86},
      organization = {IJCAI},
    }

# Manual to bibtex

    @Manual{,
      author = {Gerhard Allwein and Dave Barker-Plummer and Jon Barwise and John Etchemendy},
      title = {{LPL} Software Manual},
      publisher = {{CSLI} Publications},
      year = {1999},
      address = {Stanford, California},
      howpublished = {CD-Rom},
    }

---

    @Manual{allweinbarker?plummer:1999,
      title = {LPL Software Manual},
      author = {Gerhard Allwein and Dave Barker-Plummer and Jon Barwise and John Etchemendy},
      year = {1999},
      publisher = {CSLI Publications},
      address = {Stanford, California},
      howpublished = {CD-Rom},
    }

# MastersThesis to bibtex

    @MastersThesis{,
      author = {Murat Bayraktar},
      title = {Computer-Aided Analysis of {E}nglish Punctuation on a
                        Parsed Corpus: The Special Case of Comma},
      school = {Department of Computer Engineering and Information
                        Science, Bilkent University, Turkey},
      address = {Ankara, Turkey},
      year = {1996},
      note = {Forthcoming},
    }

---

    @MastersThesis{bayraktar:1996,
      title = {Computer-Aided Analysis of English Punctuation on a Parsed Corpus: The Special Case of Comma},
      author = {Murat Bayraktar},
      year = {1996},
      note = {Forthcoming},
      school = {Department of Computer Engineering and Information Science, Bilkent University, Turkey},
    }

# PhdThesis to bibtex

    @PhdThesis{,
      author = {David I. Beaver},
      title = {Presupposition and Assertion in Dynamic Semantics},
      school = {Centre for Cognitive Science, University of Edinburgh},
      year = {1995},
      type = {Ph.D. Dissertation},
      address = {Edinburgh},
    }

---

    @PhdThesis{beaver:1995,
      title = {Presupposition and Assertion in Dynamic Semantics},
      author = {David I. Beaver},
      year = {1995},
      school = {Centre for Cognitive Science, University of Edinburgh},
    }

# Proceedings to bibtex

    @Proceedings{,
      title = {An Abductive Framework for Negation in Disjunctive
                        Logic Programming},
      organization = {{JELIA}'96},
      year = {1996},
      editor = {Jose Julio Alferes and Luis Moniz Pereira and Eva Orlowska},
      publisher = {Springer-Verlag},
      address = {Berlin},
      missinginfo = {pages},
    }

---

    @Proceedings{anonymous:1996,
      title = {An Abductive Framework for Negation in Disjunctive Logic Programming},
      year = {1996},
      publisher = {Springer-Verlag},
      address = {Berlin},
      editor = {Jose Julio Alferes and Luis Moniz Pereira and Eva Orlowska},
      organization = {JELIA'96},
    }

# TechReport to bibtex

    @TechReport{,
      author = {John M. Aronis},
      title = {Implementing Inheritance on the Connection Machine},
      institution = {Intelligent Systems Program, University of Pittsburgh},
      number = {ISP 93-1},
      year = {1993},
      address = {Pittsburgh, PA 15260},
    }

---

    @TechReport{aronis:1993,
      title = {Implementing Inheritance on the Connection Machine},
      author = {John M. Aronis},
      year = {1993},
      address = {Pittsburgh, PA 15260},
      number = {ISP 93-1},
      institution = {Intelligent Systems Program, University of Pittsburgh},
    }

# Unpublished to bibtex

    @Unpublished{,
      author = {John M. Aronis and Foster J. Provost},
      title = {Efficiently Constructing Relational Features from Background},
      year = {1959},
      note = {Unpublished MS, Computer Science Department, University of Pittsburgh.},
      missinginfo = {Date is  guess.},
    }

---

    @Unpublished{aronisprovost:1959,
      title = {Efficiently Constructing Relational Features from Background},
      author = {John M. Aronis and Foster J. Provost},
      year = {1959},
      note = {Unpublished MS, Computer Science Department, University of Pittsburgh.},
    }

# particle names

    type: book
    title: A Handbook for Scholars
    authors:
    - family-names: Leunen
      given-names: Mary-Claire
      name-particle: van
    - family-names: Davis
      given-names: Sammy
      name-suffix: Jr.
    year: '1979'
    publisher:
      name: Knopf

---

    @Book{vanleunendavisjr?:1979,
      title = {A Handbook for Scholars},
      author = {Mary-Claire {van Leunen} and Sammy {Davis Jr.}},
      year = {1979},
      publisher = {Knopf},
    }

# From plain cff with pref citation

    @Manual{doe:2022,
      title = {My Research Software},
      author = {John Doe},
      year = {2022},
      month = {mar},
      editor = {A name},
    }

# From plain cff

    @Misc{doe,
      title = {My Research Software},
      author = {John Doe},
    }

# From file

    @InBook{vanderrealpersoniventityprojectteamconferenceentity:2017,
      title = {Book Title},
      author = {One Truly {van der Real Person IV} and {Entity Project Team Conference entity}},
      year = {2017},
      month = {mar},
      journal = {PeerJ},
      publisher = {Entity Project Team Conference entity},
      address = {22 Acacia Avenue, Citationburgh, Renfrewshire, GB},
      editor = {One Truly {van der Real Person IV} and {Entity Project Team Conference entity}},
      series = {Collection Title},
      volume = {2},
      number = {123},
      pages = {123--456},
      doi = {10.5281/zenodo.1003150},
      isbn = {978-1-89183-044-0},
      issn = {1234-543X},
      url = {http://j.mp},
      note = {A field for general notes about the reference, usable in other formats such as BibTeX.},
      chapter = {Chapter 2 - "Reference keys"},
      edition = {2nd edition},
      howpublished = {Hardcover book},
      institution = {Entity Project Team Conference entity},
      keywords = {Software, Citation},
      abstract = {Description of the book.},
      date = {2017-10-31},
      file = {book.zip},
      issuetitle = {Special Issue on Software Citation},
      pagetotal = {765},
      urldate = {2017-10-31},
      version = {0.0.1423-BETA},
      translator = {van der Real Person, IV, One Truly and {Entity Project Team Conference entity}},
    }

# Test anonymous

    @Booklet{anonymous,
      title = {A booklet},
    }

---

    @Manual{anonymous,
      title = {A manual},
    }

---

    @Misc{anonymous,
      title = {A misc},
    }

---

    @Proceedings{anonymous:1984,
      title = {proceedings},
      year = {1984},
    }

# Fallback month

    @Article{,
      title = {An Article},
      author = {John Doe},
      journal = {El Adelantado de Segovia},
      year = {1678},
      date = {1678-04-23},
    }

---

    @Article{doe:1678,
      title = {An Article},
      author = {John Doe},
      year = {1678},
      month = {apr},
      journal = {El Adelantado de Segovia},
      date = {1678-04-23},
    }

# Test BibLateX entry

    @Article{,
      author = {M. A. Kastenholz and Philippe H. Hünenbergerb},
      title = {Computation of methodology hyphen independent ionic solvation
                      free energies from molecular simulations},
      journal = {J. Chem. Phys.},
      year = {2006},
      note = {Example modified for testing purposes},
      pages = {55--65},
      date = {2006-03-15},
      file = {a_file.pdf},
      issuetitle = {Semantic {3D} Media and Content},
      translator = {Wicksteed, P. H. and {The translator factory}},
      urldate = {2006-10-01},
      pagetotal = {528},
      abstract = {The computation of ionic solvation free energies from
                      atomistic simulations is a surprisingly difficult problem that
                      has found no satisfactory solution for more than 15 years.},
      doi = {10.1063/1.2172593},
      isbn = {0-816-52066-6},
      issn = {0097-8493},
      url = {http://www.ctan.org},
    }

---

    @Article{kastenholzh?nenbergerb:2006,
      title = {Computation of methodology hyphen independent ionic solvation free energies from molecular simulations},
      author = {M. A. Kastenholz and Philippe H. Hünenbergerb},
      year = {2006},
      month = {mar},
      journal = {J. Chem. Phys.},
      pages = {55--65},
      doi = {10.1063/1.2172593},
      isbn = {0-816-52066-6},
      issn = {0097-8493},
      url = {http://www.ctan.org},
      note = {Example modified for testing purposes},
      abstract = {The computation of ionic solvation free energies from atomistic simulations is a surprisingly difficult problem that has found no satisfactory solution for more than 15 years.},
      date = {2006-03-15},
      file = {a_file.pdf},
      issuetitle = {Semantic 3D Media and Content},
      pagetotal = {528},
      urldate = {2006-10-01},
      translator = {Wicksteed, P. H. and {The translator factory}},
    }

==> cffr_0.4.0.tar.gz: cffr/tests/testthat/_snaps/cff_to_bibtex.md <==
# Article to bibtex

    @Article{knuth:1984,
      author = {{R Core Team}},
      title = {Literate Programming},
      journal = {The Computer Journal},
      year = {1984},
      volume = {27},
      number = {2},
      pages = {97--111},
      month = {January},
      keywords = {Some},
      keywords = {simple},
      keywords = {keywords},
    }

---

    @Article{rcoreteam:1984,
      title = {Literate Programming},
      author = {{R Core Team}},
      year = {1984},
      month = {jan},
      journal = {The Computer Journal},
      volume = {27},
      number = {2},
      pages = {97--111},
      keywords = {Some, simple, keywords},
    }

# Book to bibtex

    @Book{latex:companion,
      author = {Frank Mittelbach and Michel Gossens and Johannes Braams and David Carlisle and Chris Rowley},
      editor = {{{Barnes} and {Noble}}},
      title = {The LaTeX Companion},
      publisher = {Addison-Wesley Professional},
      year = {2004},
      volume = {3},
      number = {7},
      series = {The LateX Books},
      address = {Santa Monica},
      edition = {Fourth},
      month = {August},
      note = {Example modified for testing purposes},
      keywords = {Two, keyword},
    }

---

    @Book{mittelbachgossens:2004,
      title = {The LaTeX Companion},
      author = {Frank Mittelbach and Michel Gossens and Johannes Braams and David Carlisle and Chris Rowley},
      year = {2004},
      month = {aug},
      publisher = {Addison-Wesley Professional},
      address = {Santa Monica},
      editor = {{Barnes and Noble}},
      series = {The LateX Books},
      volume = {3},
      number = {7},
      note = {Example modified for testing purposes},
      edition = {Fourth},
      keywords = {Two, keyword},
    }

# Booklet to bibtex

    @Booklet{Mustermann2016,
      title = {Java Booklet},
      author = {Max Mustermann},
      howpublished = {Internet},
      address = {Stuttgart},
      month = {feb},
      year = {2016},
      note = {Example modified from Jabref},
      keywords = {java},
    }

---

    @Booklet{mustermann:2016,
      title = {Java Booklet},
      author = {Max Mustermann},
      year = {2016},
      month = {feb},
      address = {Stuttgart},
      note = {Example modified from Jabref},
      howpublished = {Internet},
    }

# InBook to bibtex with pages

    @InBook{,
      year = {2003},
      month = {oct},
      pages = {175--196},
      title = {Architectural Mismatch Tolerance},
      chapter = {Tolerances and Other Notes},
      author = {R. {de Lemos} and C. Gacek and A. Romanovsky},
      url = {http://www.cs.kent.ac.uk/pubs/2003/1773},
      publication_type = {inbook},
      submission_id = {12884_1074884456},
      isbn = {3-540-40727-8},
      editor = {A. Lalanda},
      edition = {Fifth},
      publisher = {Springer},
      volume = {2677},
      number = {234},
      address = {Lozoya},
      series = {Lecture Notes in Computer Science},
      type = {Architecting Dependable Systems},
    }

---

    @InBook{delemosgacek:2003,
      title = {Architectural Mismatch Tolerance},
      author = {R. {de Lemos} and C. Gacek and A. Romanovsky},
      year = {2003},
      month = {oct},
      publisher = {Springer},
      address = {Lozoya},
      editor = {A. Lalanda},
      series = {Lecture Notes in Computer Science},
      volume = {2677},
      number = {234},
      pages = {175--196},
      isbn = {3-540-40727-8},
      url = {http://www.cs.kent.ac.uk/pubs/2003/1773},
      chapter = {Tolerances and Other Notes},
      edition = {Fifth},
    }

# InCollection to bibtex

    @InCollection{,
      author = {Klaus Abels},
      title = {Who Gives a Damn about Minimizers in Questions?},
      booktitle = {Proceedings from Semantics and Linguistic Theory {XIII}},
      publisher = {Cornell University},
      year = {2003},
      editor = {Robert B. Young and Yuping Zhou},
      pages = {1--18},
      address = {Ithaca, New York},
      topic = {interrogatives;nl-semantics;polarity;},
    }

---

    @InCollection{abels:2003,
      title = {Who Gives a Damn about Minimizers in Questions?},
      author = {Klaus Abels},
      year = {2003},
      booktitle = {Proceedings from Semantics and Linguistic Theory XIII},
      publisher = {Cornell University},
      address = {Ithaca, New York},
      editor = {Robert B. Young and Yuping Zhou},
      pages = {1--18},
    }

# InProceedings to bibtex

    @InProceedings{,
      author = {John Aberdeen and Samuel Bayer and Sasha Caskey and Laurie Damianos and Alan Goldschen and Lynette Hirschman and Dan Loehr and Hugo Trapper},
      title = {Implementing Practical Dialogue Systems with the
                        {DARPA} Communicator Architecture},
      booktitle = {Proceedings of the {IJCAI}-99 Workshop on
                        Knowledge and Reasoning in Practical Dialogue Systems},
      year = {1999},
      editor = {Jan Alexandersson},
      pages = {81--86},
      series = {A Series},
      organization = {IJCAI},
      publisher = {International Joint Conference on Artificial Intelligence},
      address = {Murray Hill, New Jersey},
    }

---

    @InProceedings{aberdeenbayer:1999,
      title = {Implementing Practical Dialogue Systems with the DARPA Communicator Architecture},
      author = {John Aberdeen and Samuel Bayer and Sasha Caskey and Laurie Damianos and Alan Goldschen and Lynette Hirschman and Dan Loehr and Hugo Trapper},
      year = {1999},
      booktitle = {Proceedings of the IJCAI-99 Workshop on Knowledge and Reasoning in Practical Dialogue Systems},
      publisher = {International Joint Conference on Artificial Intelligence},
      address = {Murray Hill, New Jersey},
      editor = {Jan Alexandersson},
      series = {A Series},
      pages = {81--86},
      organization = {IJCAI},
    }

# Manual to bibtex

    @Manual{,
      author = {Gerhard Allwein and Dave Barker-Plummer and Jon Barwise and John Etchemendy},
      title = {{LPL} Software Manual},
      publisher = {{CSLI} Publications},
      year = {1999},
      address = {Stanford, California},
      howpublished = {CD-Rom},
    }

---

    @Manual{allweinbarker?plummer:1999,
      title = {LPL Software Manual},
      author = {Gerhard Allwein and Dave Barker-Plummer and Jon Barwise and John Etchemendy},
      year = {1999},
      publisher = {CSLI Publications},
      address = {Stanford, California},
      howpublished = {CD-Rom},
    }

# MastersThesis to bibtex

    @MastersThesis{,
      author = {Murat Bayraktar},
      title = {Computer-Aided Analysis of {E}nglish Punctuation on a
                        Parsed Corpus: The Special Case of Comma},
      school = {Department of Computer Engineering and Information
                        Science, Bilkent University, Turkey},
      address = {Ankara, Turkey},
      year = {1996},
      note = {Forthcoming},
    }

---

    @MastersThesis{bayraktar:1996,
      title = {Computer-Aided Analysis of English Punctuation on a Parsed Corpus: The Special Case of Comma},
      author = {Murat Bayraktar},
      year = {1996},
      note = {Forthcoming},
      school = {Department of Computer Engineering and Information Science, Bilkent University, Turkey},
    }

# PhdThesis to bibtex

    @PhdThesis{,
      author = {David I. Beaver},
      title = {Presupposition and Assertion in Dynamic Semantics},
      school = {Centre for Cognitive Science, University of Edinburgh},
      year = {1995},
      type = {Ph.D. Dissertation},
      address = {Edinburgh},
    }

---

    @PhdThesis{beaver:1995,
      title = {Presupposition and Assertion in Dynamic Semantics},
      author = {David I. Beaver},
      year = {1995},
      school = {Centre for Cognitive Science, University of Edinburgh},
    }

# Proceedings to bibtex

    @Proceedings{,
      title = {An Abductive Framework for Negation in Disjunctive
                        Logic Programming},
      organization = {{JELIA}'96},
      year = {1996},
      editor = {Jose Julio Alferes and Luis Moniz Pereira and Eva Orlowska},
      publisher = {Springer-Verlag},
      address = {Berlin},
      missinginfo = {pages},
    }

---

    @Proceedings{anonymous:1996,
      title = {An Abductive Framework for Negation in Disjunctive Logic Programming},
      year = {1996},
      publisher = {Springer-Verlag},
      address = {Berlin},
      editor = {Jose Julio Alferes and Luis Moniz Pereira and Eva Orlowska},
      organization = {JELIA'96},
    }

# TechReport to bibtex

    @TechReport{,
      author = {John M. Aronis},
      title = {Implementing Inheritance on the Connection Machine},
      institution = {Intelligent Systems Program, University of Pittsburgh},
      number = {ISP 93-1},
      year = {1993},
      address = {Pittsburgh, PA 15260},
    }

---

    @TechReport{aronis:1993,
      title = {Implementing Inheritance on the Connection Machine},
      author = {John M. Aronis},
      year = {1993},
      address = {Pittsburgh, PA 15260},
      number = {ISP 93-1},
      institution = {Intelligent Systems Program, University of Pittsburgh},
    }

# Unpublished to bibtex

    @Unpublished{,
      author = {John M. Aronis and Foster J. Provost},
      title = {Efficiently Constructing Relational Features from Background},
      year = {1959},
      note = {Unpublished MS, Computer Science Department, University of Pittsburgh.},
      missinginfo = {Date is  guess.},
    }

---

    @Unpublished{aronisprovost:1959,
      title = {Efficiently Constructing Relational Features from Background},
      author = {John M. Aronis and Foster J. Provost},
      year = {1959},
      note = {Unpublished MS, Computer Science Department, University of Pittsburgh.},
    }

# particle names

    type: book
    title: A Handbook for Scholars
    authors:
    - family-names: Leunen
      given-names: Mary-Claire
      name-particle: van
    - family-names: Davis
      given-names: Sammy
      name-suffix: Jr.
    year: '1979'
    publisher:
      name: Knopf

---

    @Book{vanleunendavisjr?:1979,
      title = {A Handbook for Scholars},
      author = {Mary-Claire {van Leunen} and Sammy {Davis Jr.}},
      year = {1979},
      publisher = {Knopf},
    }

# From plain cff with a citation

    @Misc{doe:1999,
      title = {title},
      author = {John Doe},
      year = {1999},
      month = {mar},
      editor = {A name},
    }

# From plain cff

    @Misc{doe,
      title = {My Research Software},
      author = {John Doe},
    }

# From file

    @InBook{vanderrealpersoniventityprojectteamconferenceentity:2017,
      title = {Book Title},
      author = {One Truly {van der Real Person IV} and {Entity Project Team Conference entity}},
      year = {2017},
      month = {mar},
      journal = {PeerJ},
      publisher = {Entity Project Team Conference entity},
      address = {22 Acacia Avenue, Citationburgh, Renfrewshire, GB},
      editor = {One Truly {van der Real Person IV} and {Entity Project Team Conference entity}},
      series = {Collection Title},
      volume = {2},
      number = {123},
      pages = {123--456},
      doi = {10.5281/zenodo.1003150},
      isbn = {978-1-89183-044-0},
      issn = {1234-543X},
      url = {http://j.mp},
      note = {A field for general notes about the reference, usable in other formats such as BibTeX.},
      chapter = {Chapter 2 - "Reference keys"},
      edition = {2nd edition},
      howpublished = {Hardcover book},
      institution = {Entity Project Team Conference entity},
      keywords = {Software, Citation},
      abstract = {Description of the book.},
      date = {2017-10-31},
      file = {book.zip},
      issuetitle = {Special Issue on Software Citation},
      pagetotal = {765},
      urldate = {2017-10-31},
      version = {0.0.1423-BETA},
      translator = {van der Real Person, IV, One Truly and {Entity Project Team Conference entity}},
    }

# Test anonymous

    @Booklet{anonymous,
      title = {A booklet},
    }

---

    @Manual{anonymous,
      title = {A manual},
    }

---

    @Misc{anonymous,
      title = {A misc},
    }

---

    @Proceedings{anonymous:1984,
      title = {proceedings},
      year = {1984},
    }

# Fallback month

    @Article{,
      title = {An Article},
      author = {John Doe},
      journal = {El Adelantado de Segovia},
      year = {1678},
      date = {1678-04-23},
    }

---

    @Article{doe:1678,
      title = {An Article},
      author = {John Doe},
      year = {1678},
      month = {apr},
      journal = {El Adelantado de Segovia},
      date = {1678-04-23},
    }

# Test BibLateX entry

    @Article{,
      author = {M. A. Kastenholz and Philippe H. Hünenbergerb},
      title = {Computation of methodology hyphen independent ionic solvation
                      free energies from molecular simulations},
      journal = {J. Chem. Phys.},
      year = {2006},
      note = {Example modified for testing purposes},
      pages = {55--65},
      date = {2006-03-15},
      file = {a_file.pdf},
      issuetitle = {Semantic {3D} Media and Content},
      translator = {Wicksteed, P. H. and {The translator factory}},
      urldate = {2006-10-01},
      pagetotal = {528},
      abstract = {The computation of ionic solvation free energies from
                      atomistic simulations is a surprisingly difficult problem that
                      has found no satisfactory solution for more than 15 years.},
      doi = {10.1063/1.2172593},
      isbn = {0-816-52066-6},
      issn = {0097-8493},
      url = {http://www.ctan.org},
    }

---

    @Article{kastenholzh?nenbergerb:2006,
      title = {Computation of methodology hyphen independent ionic solvation free energies from molecular simulations},
      author = {M. A. Kastenholz and Philippe H. Hünenbergerb},
      year = {2006},
      month = {mar},
      journal = {J. Chem. Phys.},
      pages = {55--65},
      doi = {10.1063/1.2172593},
      isbn = {0-816-52066-6},
      issn = {0097-8493},
      url = {http://www.ctan.org},
      note = {Example modified for testing purposes},
      abstract = {The computation of ionic solvation free energies from atomistic simulations is a surprisingly difficult problem that has found no satisfactory solution for more than 15 years.},
      date = {2006-03-15},
      file = {a_file.pdf},
      issuetitle = {Semantic 3D Media and Content},
      pagetotal = {528},
      urldate = {2006-10-01},
      translator = {Wicksteed, P. H. and {The translator factory}},
    }
